==> ocg_login-0.0.8.tar.gz: lib/src/blocs/login/bloc.dart <==
import 'package:ocg_app/ocg_app.dart';
import 'package:bloc/bloc.dart';
import 'package:ocg_login/src/repository/login/base.dart';
import 'event.dart';
import 'state.dart';

class LoginBloc extends Bloc<LoginEvent, LoginState> {
  final LoginRepository loginRepository;
  LoginBloc(
    this.loginRepository,
  ) : super(LoginIdleState());

  @override
  Stream<LoginState> mapEventToState(LoginEvent event) async* {
    if (event is LoginCheckEvent) {
      AppResponse<AppToken> tokenResponse = await loginRepository.getToken();
      if (tokenResponse.isSuccess) {
        yield LoginSuccessState(tokenResponse.data);
      } else {
        yield LoginErrorState(LoginError.NOT_EXISTS);
      }
    }
    if (event is LoginMobileEvent) {
      yield LoginLoadingState();

      var response = await loginRepository.sendOTP(event.mobileNumber);
      if (response.isSuccess)
        yield LoginOTPNotVerifiedState(event.mobileNumber);
      else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginOTPEvent) {
      yield LoginLoadingState();
      var response =
          await loginRepository.verifyOTP(event.mobileNumber, event.otp);
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginEmailSignupEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.createUserWithEmailAndPassword(
          event.email, event.password);
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginEmailSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signInWithEmailAndPassword(
          event.email, event.password);
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginGoogleSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signWithGoogle();
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginAppleSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signInWithApple();
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginFacebookSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signInWithFacebook();
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginLogoutEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signOut();
      if (response.isSuccess) {
        yield LoginLoggedOutState();
      } else {
        yield LoginErrorState(response.error);
      }
    }
  }
}

==> ocg_login-0.0.10.tar.gz: lib/src/blocs/login/bloc.dart <==
import 'package:ocg_app/ocg_app.dart';
import 'package:bloc/bloc.dart';
import 'package:ocg_login/src/repository/login/base.dart';
import 'event.dart';
import 'state.dart';

class LoginBloc extends Bloc<LoginEvent, LoginState> {
  final LoginRepository loginRepository;
  LoginBloc(
    this.loginRepository,
  ) : super(LoginIdleState());

  @override
  Stream<LoginState> mapEventToState(LoginEvent event) async* {
    if (event is LoginCheckEvent) {
      AppResponse<AppToken> tokenResponse = await loginRepository.getToken();
      if (tokenResponse.isSuccess) {
        yield LoginSuccessState(tokenResponse.data);
      } else {
        yield LoginNotExistsState();
      }
    }
    if (event is LoginMobileEvent) {
      yield LoginLoadingState();

      var response =
          await loginRepository.sendOTP(event.countryCode, event.mobileNumber);
      if (response.isSuccess)
        yield LoginOTPNotVerifiedState(response.data);
      else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginOTPEvent) {
      yield LoginLoadingState();
      var response =
          await loginRepository.verifyOTP(event.mobileNumber, event.otp);
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginEmailSignupEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.createUserWithEmailAndPassword(
          event.email, event.password);
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginEmailSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signInWithEmailAndPassword(
          event.email, event.password);
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginGoogleSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signWithGoogle();
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginAppleSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signInWithApple();
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginFacebookSigninEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signInWithFacebook();
      if (response.isSuccess) {
        yield LoginSuccessState(response.data);
      } else {
        yield LoginErrorState(response.error);
      }
    }
    if (event is LoginLogoutEvent) {
      yield LoginLoadingState();
      var response = await loginRepository.signOut();
      if (response.isSuccess) {
        yield LoginLoggedOutState();
      } else {
        yield LoginErrorState(response.error);
      }
    }
  }
}
